@@ -1,8 +1,8 @@
-from .sorn import Simulator, Trainer
+from sorn.sorn import Simulator, Trainer
 import logging
-from .utils import *
+from sorn.utils import *
 
 __author__ = "Saranraj Nambusubramaniyan"
-__version__ = "0.3.2"
+__version__ = "0.3.6"
 
 logging.basicConfig(level=logging.INFO)
\ No newline at end of file
